==> applet-opt-log-boot-starter-3.1.1-sources.jar: cn/sinozg/applet/biz/opt/vo/request/OptLogDataByBizIdPageRequest.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.biz.opt.vo.request;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import lombok.Data;

import java.io.Serializable;

/**
* 操作、数据日志记录表 分页请求参数
* @Description
* @Copyright Copyright (c) 2024
* @author xieyubin
* @since 2024-02-28 18:03:49
*/
@Data
@Schema(name = "OptLogDataByBizIdPageRequest", description = "操作、数据日志记录 分页请求参数")
public class OptLogDataByBizIdPageRequest implements Serializable {

    private static final long serialVersionUID = 1L;
    @Schema(description = "日志id")
    private String id;

    /** 业务id */
    @Schema(description = "业务id")
    @NotBlank(message = "业务id不能为空！")
    private String bizId;

    @Schema(description = "开始时间 yyyy-MM-dd")
    private String beginTime;

    @Schema(description = "结束时间 yyyy-MM-dd")
    private String endTime;
}

==> applet-opt-log-boot-starter-3.2.4-sources.jar: cn/sinozg/applet/biz/opt/vo/request/OptLogDataByBizIdPageRequest.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.biz.opt.vo.request;

import cn.sinozg.applet.common.utils.DateUtil;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.time.LocalTime;

/**
* 操作、数据日志记录表 分页请求参数
* @Description
* @Copyright Copyright (c) 2024
* @author xieyubin
* @since 2024-02-28 18:03:49
*/
@Data
@Schema(name = "OptLogDataByBizIdPageRequest", description = "操作、数据日志记录 分页请求参数")
public class OptLogDataByBizIdPageRequest implements Serializable {

    @Schema(description = "日志id")
    private String id;

    /** 业务id */
    @Schema(description = "业务id")
    @NotBlank(message = "业务id不能为空！")
    private String bizId;

    @Schema(description = "开始时间 yyyy-MM-dd")
    private String beginTime;

    @Schema(description = "结束时间 yyyy-MM-dd")
    private String endTime;

    @JsonIgnore
    private LocalDateTime bt;

    @JsonIgnore
    private LocalDateTime et;

    public LocalDateTime getBt() {
        if (StringUtils.isNotBlank(beginTime)) {
            return DateUtil.parseDate(beginTime).atTime(LocalTime.MIN);
        }
        return bt;
    }

    public LocalDateTime getEt() {
        if (StringUtils.isNotBlank(endTime)) {
            return DateUtil.parseDate(endTime).atTime(LocalTime.MAX);
        }
        return et;
    }
}
